@@ -1,20 +1,12 @@
 test_that("obital speed computation works", {
-  spec <- t(vapply(1:10, \(h) jonswap(h, tp = 12)$spec, FUN.VALUE = numeric(36)))
-  orb_speed_bottom <- compute_orbital_speeds(spec,
-    rscd_freq,
-    depth = 50,
-    z = 0
-  )
-  orb_speed_half <- compute_orbital_speeds(spec,
-    rscd_freq,
-    depth = 50,
-    z = 25
-  )
-  orb_speed_top <- compute_orbital_speeds(spec,
-    rscd_freq,
-    depth = 50,
-    z = 50
-  )
+  spec <- t(vapply(
+    1:10,
+    \(h) jonswap(h, tp = 12)$spec,
+    FUN.VALUE = numeric(36)
+  ))
+  orb_speed_bottom <- compute_orbital_speeds(spec, rscd_freq, depth = 50, z = 0)
+  orb_speed_half <- compute_orbital_speeds(spec, rscd_freq, depth = 50, z = 25)
+  orb_speed_top <- compute_orbital_speeds(spec, rscd_freq, depth = 50, z = 50)
   orb_speed_bottom_spec <- compute_orbital_speeds(
     spec,
     rscd_freq,
