@@ -9,15 +9,18 @@ test_that("we can plot the 2D spectrum", {
   expect_warning(print(plot_not_normalized))
   expect_warning(print(plot_from_date))
   suppressWarnings({
-    vdiffr::expect_doppelganger("Specifying index",
+    vdiffr::expect_doppelganger(
+      "Specifying index",
       plot_from_index,
       variant = Sys.info()[["sysname"]]
     )
-    vdiffr::expect_doppelganger("Un-normalized 2D spectra",
+    vdiffr::expect_doppelganger(
+      "Un-normalized 2D spectra",
       plot_not_normalized,
       variant = Sys.info()[["sysname"]]
     )
-    vdiffr::expect_doppelganger("Plot by date",
+    vdiffr::expect_doppelganger(
+      "Plot by date",
       plot_from_date,
       variant = Sys.info()[["sysname"]]
     )
